@@ -31,7 +31,8 @@ import time
 from time import localtime,strftime
 # --------------------- end edit-----------------------------------------------------
 
-CPDIR = os.path.join(os.environ['HOME'], '.curphoo')
+CPVER = '0.4.3-2'
+CPDIR = os.path.join(os.environ['HOME'], '.curphoo') + "-" + CPVER
 CPRC = os.path.join(CPDIR, 'curphoorc')
 CPBUDDIES = os.path.join(CPDIR, 'buds')
 CPBUDDIESTXT = os.path.join(CPDIR, 'buddies')
