@@ -17,7 +17,7 @@
 # along with Curphoo; if not, write to the Free Software
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
-# $Id: cmdparser.py,v 1.14 2006/08/14 18:02:25 BoW4IamTheBOFH Exp $
+# $Id: cmdparser.py,v 1.13 2006/08/14 16:28:40 BoW4IamTheBOFH Exp $
 ##
 
 
@@ -38,7 +38,7 @@ AWAY_MSG = "JuGgLiNg"
 
 # I will be kicking ass if adhoc releases cause our users confusion (matt)
 
-PLUG_MSG = "is using Curphoo 0.4.3 http://savannah.nongnu.org/projects/curphoo/"
+PLUG_MSG = "is using Curphoo " + Session.CPVER + " http://savannah.nongnu.org/projects/curphoo/"
 
 def btk(cli, sess, statusbar):
 	if sess.afk:
