@@ -25,6 +25,7 @@ import sys
 import os
 import re
 import babelizer
+import Session
 #import copy
 
 def wordwrap(win, text, indent=2):
@@ -487,14 +488,18 @@ def status(win, sess):
 		s = '%s%s' % (s, ' '*(curses.COLS - (len(' -AWAY-') + len(s))))
 		s = '%s%s' % (s, '-AWAY-')
 	else:
-		s = '[%s] %s@%s:%s C:%s I:%s B:%s' % (
+		s = '[%s] %s@%s:%s C:%s I:%s B:%s UID:%s RE:%s Excludes:%s  Version: %s' % (
 			sess.time,
 			sess.user,
 			sess.server[:3],
 			sess.room,
 			len(sess.users),
 			len(sess.ignores),
-			len(sess.buddies))
+			len(sess.buddies),
+			len(sess.uidregex),
+			len(sess.myregex),
+			len(sess.excludes),
+			Session.CPVER)
 	s = s[:curses.COLS-1]
 	win.erase()
 	win.addstr(s)
